@@ -11,7 +11,11 @@ use strict;
 use warnings;
  
 use Exporter;
+
 our @ISA = qw(Exporter);
+
+our @EXPORT = qw/sql_column_names/;
+
 our @EXPORT_OK = qw(
 		       fix_name	
 		       fix_reserved	
@@ -831,15 +835,16 @@ sub fix_chars {
     # print STDERR "Before: $w";
     for ($w) {
 	s/^\s+|\s+$//g;
-	
+
 	s/\-(\d+)/_minus_$1_/g;
 	s/\&/_and_/g;
 	s/\+/_plus_/g;
+	s/\s\-\s/_minus_/g;
 	s/\//_or_/g;
 	s/\*/times/g;
 	s/%/percent/g;
 	s/#/nr/g;
-	
+
 	s/\-/_/g;
 	s/\s/_/g;
 	s/\://g;
@@ -848,9 +853,7 @@ sub fix_chars {
 
 	s/\W/_/g;
 	s/__+/_/g;
-	    
 	s/^_//g;
-	
 	$_ = lc;
     }
     return $w 
@@ -861,7 +864,7 @@ sub fix_ordinal {
     for ($w) {
 	my $NUMBER_RE  = qr/\b(?:[+-]?)(?=\d|\.\d)\d*(?:\.\d*)?(?:[Ee](?:[+-]?\d+))?/;
 	my $ORDINAL_NUMBER_RE  = qr/($NUMBER_RE)(?:st|nd|rd|th)\b/;
-	
+
 	while (/($ORDINAL_NUMBER_RE)/) {
 	    my ($n) = ($1 =~ /(\d+)/);
 	    $n = num2en_ordinal($n);
@@ -906,6 +909,25 @@ sub fix_names {
     return @w;
 }
 
+sub sql_column_names {
+    my @cols_in = fix_names(@_);
+    my %seen;
+
+    $seen{$_}++ for @cols_in;
+    my %seq;
+    my @cols_out;
+
+    for (@cols_in) {
+	if ($seen{$_} > 1) {
+	    push @cols_out, sprintf '%s_%02d', $_, ++$seq{$_};
+	} else {
+	    push @cols_out, $_;
+	}
+    }
+    s/__/_/g for @cols_out;
+    return @cols_out;
+}
+
 1;
 
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
@@ -927,31 +949,45 @@ L<String::CamelCase>
 L<Lingua::EN::Numbers> 
 
 
-=head1 METHODS
+=head1 FUNCTIONS
+
+=head2 sql_column_names
+
+  sql_column_names(@column_name_input)
+
+Returns SQL-compatible and unique column names from a series of strings.
+
+=head2 fix_name, fix_names
+
+ fix_name();
+ fix_names();
+
+Combine fix_number(), fix_ordinal(), fix_reserved() and fix_chars()
 
 =head2 fix_chars
 
  fix_chars();
 
-=head2 fix_name, fix_names
-
- fix_name();
-
- fix_names();
+Eliminates invalid characters from column name
 
 =head2 fix_number
 
- fix_number('12 months');  # twelve_months
+ fix_number('12 months');        # twelve_months
  fix_number('52 weeks total');   # fifty_two_weeks_total
 
+Eliminates starting numbers from string by traslating them to text
+
 =head2 fix_ordinal
 
- fix_ordinal('1st_date'); # first_date
+ fix_ordinal('1st_date');        # first_date
+
+Fixes ordinals in the string
 
 =head2 fix_reserved
 
- fix_reserved('group');   # group_
+ fix_reserved('group');         # group_
 
+Adds an underscore to column whose name is a reserved word.
 
 =cut
 
